@@ -4,9 +4,9 @@ from typing import List, Callable, Union
 from PIL import Image
 
 from .structures import *
-from .remote.rustplus_proto import *
-from .remote import RustRemote, HeartBeat
-from ..commands import CommandOptions
+from .remote.rustplus_proto import AppEmpty, AppRequest
+from .remote import RustRemote, HeartBeat, MapEventListener
+from ..commands import CommandOptions, CommandHandler
 from ..commands.command_data import CommandData
 from ..exceptions import *
 from ..utils import RegisteredListener, deprecated
@@ -44,7 +44,7 @@ class BaseRustSocket:
         self.seq = 1
         self.command_options = command_options
         self.raise_ratelimit_exception = raise_ratelimit_exception
-        self.listener_seq = 0
+        self.marker_listener = MapEventListener(self)
 
         self.remote = RustRemote(
             ip=self.ip,
@@ -142,16 +142,87 @@ class BaseRustSocket:
 
         await self.remote.send_message(app_request)
 
+    async def switch_server(
+        self,
+        ip: str = None,
+        port: str = None,
+        steam_id: int = None,
+        player_token: int = None,
+        command_options: CommandOptions = None,
+        raise_ratelimit_exception: bool = True,
+        connect: bool = False,
+        use_proxy: bool = False,
+    ) -> None:
+        """
+        Disconnects and replaces server params, allowing the socket to connect to a new server.
+
+        :param raise_ratelimit_exception: Whether to raise an exception or wait
+        :param command_options: The command options
+        :param ip: IP of the server
+        :param port: Port of the server
+        :param player_token: The player Token
+        :param steam_id: Steam id of the player
+        :param connect: bool indicating if socket should automatically self.connect()
+        :param use_proxy: Whether to use the facepunch proxy
+        :return: None
+        """
+        if ip is None:
+            raise ValueError("Ip cannot be None")
+        if port is None:
+            raise ValueError("Port cannot be None")
+        if steam_id is None:
+            raise ValueError("SteamID cannot be None")
+        if player_token is None:
+            raise ValueError("PlayerToken cannot be None")
+
+        # disconnect before redefining
+        await self.disconnect()
+
+        # Reset basic credentials
+        self.ip = ip
+        self.port = port
+        self.steam_id = steam_id
+        self.player_token = player_token
+        self.seq = 1
+
+        # Deal with commands
+
+        if command_options is not None:
+            self.command_options = command_options
+            self.remote.command_options = command_options
+            if self.remote.use_commands:
+                self.remote.command_handler.command_options = command_options
+            else:
+                self.remote.use_commands = True
+                self.remote.command_handler = CommandHandler(self.command_options)
+
+        self.raise_ratelimit_exception = raise_ratelimit_exception
+
+        self.remote.ip = ip
+        self.remote.port = port
+        self.remote.use_proxy = use_proxy
+
+        # reset ratelimiter
+        self.remote.ratelimiter.reset()
+        self.remote.conversation_factory = ConversationFactory(self)
+        # remove entity events
+        self.remote.event_handler.clear_entity_events()
+        # reset marker listener
+        self.marker_listener.persistent_ids.clear()
+
+        if connect:
+            await self.connect()
+
     def command(
         self,
         coro: Callable = None,
         aliases: List[str] = None,
-        alais_func: Callable = None,
+        alias_func: Callable = None,
     ) -> Union[Callable, RegisteredListener]:
         """
         A coroutine decorator used to register a command executor
 
-        :param alais_func: The function to test the aliases against
+        :param alias_func: The function to test the aliases against
         :param aliases: The aliases to register the command under
         :param coro: The coroutine to call when the command is called
         :return: RegisteredListener - The listener object | Callable - The callable func for the decorator
@@ -161,7 +232,7 @@ class BaseRustSocket:
             coro = coro.get_coro()
 
         if asyncio.iscoroutinefunction(coro):
-            cmd_data = CommandData(coro, asyncio.get_event_loop(), aliases, alais_func)
+            cmd_data = CommandData(coro, asyncio.get_event_loop(), aliases, alias_func)
             self.remote.command_handler.register_command(cmd_data)
             return RegisteredListener(coro.__name__, (cmd_data.coro, cmd_data.loop))
 
@@ -173,7 +244,7 @@ class BaseRustSocket:
             if isinstance(coro, RegisteredListener):
                 coro = coro.get_coro()
 
-            cmd_data = CommandData(coro, asyncio.get_event_loop(), aliases, alais_func)
+            cmd_data = CommandData(coro, asyncio.get_event_loop(), aliases, alias_func)
             self.remote.command_handler.register_command(cmd_data)
             return RegisteredListener(coro.__name__, (cmd_data.coro, cmd_data.loop))
 
@@ -262,6 +333,33 @@ class BaseRustSocket:
 
         return wrap_func
 
+    async def start_marker_event_listener(self, delay: int = 5) -> None:
+        """
+        Starts the marker event listener
+        :param delay: The delay between marker checking
+        :return: None
+        """
+        self.marker_listener.start(delay)
+
+    def marker_event(self, coro) -> RegisteredListener:
+        """
+        A Decorator to register an event listener for new map markers
+
+        :param coro: The coroutine to call when the command is called
+        :return: RegisteredListener - The listener object
+        """
+
+        if isinstance(coro, RegisteredListener):
+            coro = coro.get_coro()
+
+        if not self.marker_listener:
+            raise ValueError("Marker listener not started")
+
+        data = (coro, asyncio.get_event_loop())
+        listener = RegisteredListener("map_marker", data)
+        self.marker_listener.add_listener(listener)
+        return listener
+
     def protobuf_received(self, coro) -> RegisteredListener:
         """
         A Decorator to register an event listener for protobuf being received on the websocket
@@ -286,6 +384,8 @@ class BaseRustSocket:
         """
 
         if isinstance(listener, RegisteredListener):
+            if listener.listener_id == "map_marker":
+                return self.marker_listener.remove_listener(listener)
             return self.remote.remove_listener(listener)
         return False
 
